@@ -1,7 +1,7 @@
 import numpy as np
 
-from models.rule_based_models import BS_helpers
-from models.rule_based_models import crossplot_helpers
+from akerbp.models.rule_based_models import BS_helpers
+from akerbp.models.rule_based_models import crossplot_helpers
 
 def flag_dencorr(df_well, y_pred=None, **kwargs):
     """
